<?php

namespace App\Http\Controllers;

use App\Models\Company;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Hash;

class CompanyController extends Controller
{
    public function index()
    {
        return view('dashforms.company.addcompany');
    }

    public function create(Request $request)
    {

        $imagename = time() . '.' . $request->image->extension();
        $request->image->move(public_path('company_images'), $imagename);

        /*$request->validate([
            'name' => 'required|string|max:255',
            'image' => 'image',
            'vat' => 'required|string|max:255',
            'address' => 'required|string|max:255',
            'phone' => 'required|string|max:255',
            'email' => 'required|email|max:255|unique:companies,email,',
            'password' => 'required|string|min:8|max:255',
        ]);*/

        $company = new Company();
        $company->name = $request->name;
        $company->image = $imagename;
        $company->vat = $request->vat;
        $company->address = $request->address;
        $company->phone = $request->phone;
        $company->email = $request->email;
        $company->password = Hash::make($request->password);
        $company->save();

        // Redirect back with success message
        return redirect()->route('company.show')->with('success', 'Company created successfully!');
    }

    public function show(Request $request)
    {

        $search = $request->input('search');
        $company = Company::when($search, function ($query) use ($search) {
            return $query->where('name', 'LIKE', '%' . $search . '%')
                ->orWhere('address', 'LIKE', '%' . $search . '%')
                ->orWhere('email', 'LIKE', '%' . $search . '%');
        })->paginate(2);

        return view('dashforms.company.showcompany', compact('company', 'search'));
    }


    public function edit($id)
    {
        $company = Company::find($id);
        return view('dashforms.company.updatecompany', compact('company'));
    }

    public function update(Request $request, $id)
    {
        $request->validate([
            'name' => 'required|string|max:255',
            'image' => 'image',
            'vat' => 'required|string|max:255',
            'address' => 'required|string|max:255',
            'phone' => 'required|string|max:255',
            'email' => 'required|email|max:255|unique:companies,email,' . $id,
            'password' => 'required|string|min:8|max:255',
        ]);

        $company = Company::find($id);

        $company->name = $request->name;
        $company->vat = $request->vat;
        $company->address = $request->address;
        $company->phone = $request->phone;
        $company->email = $request->email;
        $company->password = Hash::make($request->password);

        if ($request->hasFile('image')) {
            $imageName = time() . '.' . $request->image->extension();
            $request->image->move(public_path('company_images'), $imageName);
            $company->image = $imageName;
        }

        $company->save();

        return redirect()->back()->with('success', 'Company updated successfully!');
    }


    public function delete($id)
    {
        $company = Company::find($id);
        $company->delete();
        return redirect()->back()->with('success', 'Company Deleted successfully!');
    }
}
