<?php

namespace App\Http\Controllers;

use App\Models\Designation;
use Illuminate\Http\Request;

class DesignationController extends Controller
{
    /**
     * Display a listing of the resource.
     */
    public function index()
    {
        $designation = Designation::all();
        return view('dashforms.designation.adddesignation', compact('designation'));
    }

    /**
     * Show the form for creating a new resource.
     */
    public function create(Request $request)
    {
        try {
            $designation = new Designation();
            $designation->designation = $request->designation;
            $designation->save();
            return redirect()->back()->with('success', 'Designation Added Successfully!');
        } catch (\Exception $e) {
            return redirect()->back()->with('error', 'Failed to add designation. Please try again.');
        }
    }

    public function show()
    {
        $designation = Designation::paginate(10);
        return view('dashforms.designation.adddesignation', compact('designation'));
    }

    public function search(Request $request)
    {
        $search = $request->input('search');
        $designation = Designation::when($search, function ($query) use ($search) {
            return $query->where('designation', 'LIKE', '%' . $search . '%');
        });

        return view('dashforms.designation.adddesignation', compact('designation', 'search'));
    }


    /**
     * Show the form for editing the specified resource.
     */
    public function edit($id)
    {
        try {
            $designation = Designation::find($id);
            return view('dashforms.designation.updatedesignation', compact('designation'));
        } catch (\Exception $e) {
            return redirect()->back()->with('error', 'Failed to retrieve designation details.');
        }
    }

    /**
     * Update the specified resource in storage.
     */
    public function update(Request $request, $id)
    {
        try {
            $designation =  Designation::find($id);
            $designation->designation = $request->designation;
            $designation->save();
            return redirect()->route('designation.show')->with('success', 'Designation Updated Successfully!');
        } catch (\Exception $e) {
            return redirect()->route('designation.show')->with('error', 'Failed to update designation. Please try again.');
        }
    }

    /**
     * Remove the specified resource from storage.
     */
    public function delete($id)
    {
        try {
            $designation =  Designation::find($id);
            $designation->delete();
            return redirect()->back()->with('success', 'Designation Deleted Successfully!');
        } catch (\Exception $e) {
            return redirect()->back()->with('error', 'Failed to delete designation. Please try again.');
        }
    }
}
