<?php

namespace App\Http\Controllers;

use App\Models\Company;
use App\Models\Designation;
use App\Models\Users;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Hash;

class UsersController extends Controller
{

    public function index()
    {
        $users = Users::all();
        $companies = Company::all();
        $designation = Designation::all(); 
        return view('dashforms.users.addusers', compact('companies', 'designation', 'users'));
    }



    public function create(Request $request)
    {

        $users = new Users();

        /*$request->validate([
            'name' => 'required|string|max:255',
            'company_id' => 'required|exists:companies,id',
            'designation_id' => 'required|exists:designations,id',
            'email' => 'required|email|max:255',
            'phone' => 'required|string|max:255',
            'password' => 'nullable|string|min:8|max:255',
        ]);*/


        $users->name = $request->name;
        $users->company_id = $request->company_id;
        $users->designation_id = $request->designation_id;
        $users->email = $request->email;
        $users->phone = $request->phone;
        $users->password = Hash::make($request->password);
        $users->save();
        return redirect()->back()->with('success', 'Users Added Successfully!');
    }


    public function show(Request $request)
    {
        $users = Users::paginate(5);
        $search = '';

        return view('dashforms.users.showusers', compact('users', 'search'));
    }

    public function search(Request $request)
    {
        $search = $request->input('search');
        $users = Users::when($search, function ($query) use ($search) {
            return $query->where('name', 'LIKE', '%' . $search . '%')
                ->orWhere('email', 'LIKE', '%' . $search . '%');
        })->paginate(5);

        return view('dashforms.users.showusers', compact('users', 'search'));
    }



    public function edit($user)
    {
        $users = Users::findOrFail($user);
        return view('dashforms.users.updateusers', compact('users'));
    }



    public function usersupdate(Request $request, $id)
    {
        $request->validate([
            'name' => 'required|string|max:255',
            'company_id' => 'required|exists:companies,id',
            'designation_id' => 'required|exists:designations,id',
            'email' => 'required|email|max:255',
            'phone' => 'required|string|max:255',
            'password' => 'nullable|string|min:8|max:255',
        ]);

        $user = Users::findOrFail($id);
        if (!$user) {
            return redirect()->back()->with('error', 'User not found!');
        }
        $user->name = $request->name;
        $user->company_id = $request->company_id;
        $user->designation_id = $request->designation_id;
        $user->email = $request->email;
        $user->phone = $request->phone;
        if ($request->filled('password')) {
            $user->password = Hash::make($request->password);
        }
        $user->save();
        return redirect()->back()->with('success', 'User Updated successfully!');
    }


    public function delete($id)
    {
        $users = Users::find($id);
        $users->delete();
        return redirect()->back()->with('success', 'Users Deleted Successfully!');
    }
}
