<?php

namespace App\Traits;

use App\Models\Permission;
use App\Models\Role;

trait HasPermissionsTrait
{
    // Given permissions
    public function getAllPermissions($permission)
    {
        return Permission::whereIn('slug', $permission)->get();
    }

    // Check if user has a specific permission
    public function hasPermission($permission)
    {
        return (bool) $this->permissions->where('slug', $permission->slug)->count();
    }

    // Check if user has any of the given roles
    public function hasRole($roles)
    {
        return $this->roles->whereIn('slug', $roles)->isNotEmpty();
    }

    public function hasPermissionTo($permissions)
    {
        return $this->hasPermissionThroughRole($permissions) || $this->hasPermission($permissions);
    }

    public function hasPermissionThroughRole($permissions)
    {
        foreach ($this->roles as $role) {
            if ($role->permissions->whereIn('slug', $permissions)->isNotEmpty()) {
                return true;
            }
        }
        return false;
    }

    public function givePermissionTo($permissions)
    {
        $permissions = $this->getAllPermissions($permissions);
        if ($permissions->isEmpty()) {
            return $this;
        }
        $this->permissions()->saveMany($permissions);
        return $this;
    }

    public function permissions()
    {
        return $this->belongsToMany(Permission::class, 'users_permissions');
    }

    public function roles()
    {
        return $this->belongsToMany(Role::class, 'users_roles');
    }
}
